==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaLq.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 林权属性结构
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_lq"
)
public class BaLq implements Serializable {

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String fbf;

    @XmlAttribute
    private float syqmj;

    @XmlAttribute
    private Date ldsyqssj;

    @XmlAttribute
    @Nullable
    private Date ldsyjssj;

    @XmlAttribute
    @Nullable
    private String ldsyqxz;

    @XmlAttribute
    @Nullable
    private String sllmsyqr1;

    @XmlAttribute
    @Nullable
    private String sllmsyqr2;

    @XmlAttribute
    private String zysz;

    @XmlAttribute
    private int zs;

    @XmlAttribute
    private String lz;

    @XmlAttribute
    private String qy;

    @XmlAttribute
    private int zlnd;

    @XmlAttribute
    private String lb;

    @XmlAttribute
    private String xb;

    @XmlAttribute
    @Nullable
    private String xdm;

    @XmlAttribute
    private String bdcqzh;

    @XmlAttribute
    @qxdm
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    private String qszt;

    @XmlAttribute
    @Id
    @id
    private String id;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    @ssywh
    private String ssywh;

    @XmlAttribute
    private String fbfdm;

    @XmlAttribute
    private String ldsyqx;

    @XmlAttribute
    private String sllb;

    @sqlx
    private String sqlx;

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getFbfdm() {
        return fbfdm;
    }

    public void setFbfdm(String fbfdm) {
        this.fbfdm = fbfdm;
    }

    public String getLdsyqx() {
        return ldsyqx;
    }

    public void setLdsyqx(String ldsyqx) {
        this.ldsyqx = ldsyqx;
    }

    public String getSllb() {
        return sllb;
    }

    public void setSllb(String sllb) {
        this.sllb = sllb;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public String getFbf() {
        return fbf;
    }

    public float getSyqmj() {
        return syqmj;
    }

    public Date getLdsyqssj() {
        return ldsyqssj;
    }

    public Date getLdsyjssj() {
        return ldsyjssj;
    }

    public String getLdsyqxz() {
        return ldsyqxz;
    }

    public String getSllmsyqr1() {
        return sllmsyqr1;
    }

    public String getSllmsyqr2() {
        return sllmsyqr2;
    }

    public String getZysz() {
        return zysz;
    }

    public int getZs() {
        return zs;
    }

    public String getLz() {
        return lz;
    }

    public String getQy() {
        return qy;
    }

    public int getZlnd() {
        return zlnd;
    }

    public String getLb() {
        return lb;
    }

    public String getXb() {
        return xb;
    }

    public String getXdm() {
        return xdm;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setFbf(String fbf) {
        this.fbf = fbf;
    }

    public void setSyqmj(float syqmj) {
        this.syqmj = syqmj;
    }

    public void setLdsyqssj(Date ldsyqssj) {
        this.ldsyqssj = ldsyqssj;
    }

    public void setLdsyjssj(Date ldsyjssj) {
        this.ldsyjssj = ldsyjssj;
    }

    public void setLdsyqxz(String ldsyqxz) {
        this.ldsyqxz = ldsyqxz;
    }

    public void setSllmsyqr1(String sllmsyqr1) {
        this.sllmsyqr1 = sllmsyqr1;
    }

    public void setSllmsyqr2(String sllmsyqr2) {
        this.sllmsyqr2 = sllmsyqr2;
    }

    public void setZysz(String zysz) {
        this.zysz = zysz;
    }

    public void setZs(int zs) {
        this.zs = zs;
    }

    public void setLz(String lz) {
        this.lz = lz;
    }

    public void setQy(String qy) {
        this.qy = qy;
    }

    public void setZlnd(int zlnd) {
        this.zlnd = zlnd;
    }

    public void setLb(String lb) {
        this.lb = lb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public void setXdm(String xdm) {
        this.xdm = xdm;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

}

==> realestate-supervise-common-1.1.0-20251208.011103-73-sources.jar: cn/gtmap/realestate/supervise/entity/BaLq.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 林权属性结构
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_lq"
)
public class BaLq implements Serializable {

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String fbf;

    @XmlAttribute
    private float syqmj;

    @XmlAttribute
    private Date ldsyqssj;

    @XmlAttribute
    @Nullable
    private Date ldsyjssj;

    @XmlAttribute
    @Nullable
    private String ldsyqxz;

    @XmlAttribute
    @Nullable
    private String sllmsyqr1;

    @XmlAttribute
    @Nullable
    private String sllmsyqr2;

    @XmlAttribute
    private String zysz;

    @XmlAttribute
    private int zs;

    @XmlAttribute
    private String lz;

    @XmlAttribute
    private String qy;

    @XmlAttribute
    private int zlnd;

    @XmlAttribute
    private String lb;

    @XmlAttribute
    private String xb;

    @XmlAttribute
    @Nullable
    private String xdm;

    @XmlAttribute
    private String bdcqzh;

    @XmlAttribute
    @qxdm
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    private String qszt;

    @XmlAttribute
    @Id
    @id
    private String id;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    @ssywh
    private String ssywh;

    @XmlAttribute
    private String fbfdm;

    @XmlAttribute
    private String ldsyqx;

    @XmlAttribute
    private String sllb;

    @sqlx
    private String sqlx;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段开始===============

    /** 流转合同代码 */
    @XmlAttribute
    private String lzhtdm;

    /** 承包合同 */
    @XmlAttribute
    private String cbht;

    /** 流转合同 */
    @XmlAttribute
    private String lzht;

    /** 原不动产单元号 */
    @XmlAttribute
    private String ybdcdyh;

    /** 用地用海分类代码 */
    @XmlAttribute
    private String ydyhfldm;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段结束===============

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getFbfdm() {
        return fbfdm;
    }

    public void setFbfdm(String fbfdm) {
        this.fbfdm = fbfdm;
    }

    public String getLdsyqx() {
        return ldsyqx;
    }

    public void setLdsyqx(String ldsyqx) {
        this.ldsyqx = ldsyqx;
    }

    public String getSllb() {
        return sllb;
    }

    public void setSllb(String sllb) {
        this.sllb = sllb;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public String getFbf() {
        return fbf;
    }

    public float getSyqmj() {
        return syqmj;
    }

    public Date getLdsyqssj() {
        return ldsyqssj;
    }

    public Date getLdsyjssj() {
        return ldsyjssj;
    }

    public String getLdsyqxz() {
        return ldsyqxz;
    }

    public String getSllmsyqr1() {
        return sllmsyqr1;
    }

    public String getSllmsyqr2() {
        return sllmsyqr2;
    }

    public String getZysz() {
        return zysz;
    }

    public int getZs() {
        return zs;
    }

    public String getLz() {
        return lz;
    }

    public String getQy() {
        return qy;
    }

    public int getZlnd() {
        return zlnd;
    }

    public String getLb() {
        return lb;
    }

    public String getXb() {
        return xb;
    }

    public String getXdm() {
        return xdm;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setFbf(String fbf) {
        this.fbf = fbf;
    }

    public void setSyqmj(float syqmj) {
        this.syqmj = syqmj;
    }

    public void setLdsyqssj(Date ldsyqssj) {
        this.ldsyqssj = ldsyqssj;
    }

    public void setLdsyjssj(Date ldsyjssj) {
        this.ldsyjssj = ldsyjssj;
    }

    public void setLdsyqxz(String ldsyqxz) {
        this.ldsyqxz = ldsyqxz;
    }

    public void setSllmsyqr1(String sllmsyqr1) {
        this.sllmsyqr1 = sllmsyqr1;
    }

    public void setSllmsyqr2(String sllmsyqr2) {
        this.sllmsyqr2 = sllmsyqr2;
    }

    public void setZysz(String zysz) {
        this.zysz = zysz;
    }

    public void setZs(int zs) {
        this.zs = zs;
    }

    public void setLz(String lz) {
        this.lz = lz;
    }

    public void setQy(String qy) {
        this.qy = qy;
    }

    public void setZlnd(int zlnd) {
        this.zlnd = zlnd;
    }

    public void setLb(String lb) {
        this.lb = lb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public void setXdm(String xdm) {
        this.xdm = xdm;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getLzhtdm() {
        return lzhtdm;
    }

    public void setLzhtdm(String lzhtdm) {
        this.lzhtdm = lzhtdm;
    }

    public String getCbht() {
        return cbht;
    }

    public void setCbht(String cbht) {
        this.cbht = cbht;
    }

    public String getLzht() {
        return lzht;
    }

    public void setLzht(String lzht) {
        this.lzht = lzht;
    }

    public String getYbdcdyh() {
        return ybdcdyh;
    }

    public void setYbdcdyh(String ybdcdyh) {
        this.ybdcdyh = ybdcdyh;
    }

    public String getYdyhfldm() {
        return ydyhfldm;
    }

    public void setYdyhfldm(String ydyhfldm) {
        this.ydyhfldm = ydyhfldm;
    }
}
